var opencl_2matrix__operations_8hpp =
[
    [ "am", "opencl_2matrix__operations_8hpp.html#aea7225cb76eda44509d42ec0e824a184", null ],
    [ "ambm", "opencl_2matrix__operations_8hpp.html#a7a3df357024a5414f6731b34ee275c80", null ],
    [ "ambm_m", "opencl_2matrix__operations_8hpp.html#a36588f4299e97d8505d17da3b5ddb266", null ],
    [ "bidiag_pack", "opencl_2matrix__operations_8hpp.html#a37fbfb949aae5a860d0308717e5b4ff5", null ],
    [ "bidiag_pack_svd", "opencl_2matrix__operations_8hpp.html#ae9e45a4202d75a28076b78d133ba9379", null ],
    [ "convert", "opencl_2matrix__operations_8hpp.html#a4e7dbe07ee5433438da8435cdb1a08ee", null ],
    [ "copy_vec", "opencl_2matrix__operations_8hpp.html#a5d5b4fe8827c4d4da9f2df19cf8ee971", null ],
    [ "element_kernel_for_matrix", "opencl_2matrix__operations_8hpp.html#ae63e075deb555fd0ef79218d5a913d9a", null ],
    [ "element_op", "opencl_2matrix__operations_8hpp.html#a8dd7386eb70a19d9d818b5ba57512d57", null ],
    [ "element_op", "opencl_2matrix__operations_8hpp.html#aba191367e3a3d0f0f603df72046e09e7", null ],
    [ "givens_next", "opencl_2matrix__operations_8hpp.html#aceca2a25a53f4b5c0dd836c8d024b170", null ],
    [ "house_update_A_left", "opencl_2matrix__operations_8hpp.html#a42d8cc5fddc8d8fe7819428f3570d8d7", null ],
    [ "house_update_A_right", "opencl_2matrix__operations_8hpp.html#aa37f02ed2a2f38dfea3abbfdeb5aab95", null ],
    [ "house_update_QL", "opencl_2matrix__operations_8hpp.html#a786d68766ad5e6b6fb239274efde0bf7", null ],
    [ "kernel_for_matrix", "opencl_2matrix__operations_8hpp.html#acb933cf08a45fa63d016111dfafa4791", null ],
    [ "legacy_kernel_for_matrix", "opencl_2matrix__operations_8hpp.html#aa42a34c8e153495ac317c599824123d4", null ],
    [ "matrix_assign", "opencl_2matrix__operations_8hpp.html#a2db93608afb5e8b93a0ed5c1df92b61c", null ],
    [ "matrix_column", "opencl_2matrix__operations_8hpp.html#a4b7f757f629ae312a7e949f73aec7eb8", null ],
    [ "matrix_diag_from_vector", "opencl_2matrix__operations_8hpp.html#a1b350268a70fb6d032bb0360a1157584", null ],
    [ "matrix_diag_to_vector", "opencl_2matrix__operations_8hpp.html#a3ca5ea18659312a9857abb74504465e1", null ],
    [ "matrix_diagonal_assign", "opencl_2matrix__operations_8hpp.html#a5588877cfe1610e81fff4f915fe7ada8", null ],
    [ "matrix_row", "opencl_2matrix__operations_8hpp.html#ac5c16bfd288a10e6a2897b86747df98b", null ],
    [ "prod_impl", "opencl_2matrix__operations_8hpp.html#a18a93d38ca1eff472149093974edb5cb", null ],
    [ "prod_impl", "opencl_2matrix__operations_8hpp.html#a16366a34aab924b279bcd2b4f403a159", null ],
    [ "scaled_rank_1_update", "opencl_2matrix__operations_8hpp.html#aa1db022508f1ca9f0a42269205ac2565", null ],
    [ "trans", "opencl_2matrix__operations_8hpp.html#a72bf0d80c0608b5645d06703c7807253", null ],
    [ "SVD_BIDIAG_PACK_KERNEL", "opencl_2matrix__operations_8hpp.html#a6c692160febc1bf0c8c1b3f14609843b", null ],
    [ "SVD_COPY_COL_KERNEL", "opencl_2matrix__operations_8hpp.html#a83f95bb0dba31593bfdea7d48825ef45", null ],
    [ "SVD_COPY_ROW_KERNEL", "opencl_2matrix__operations_8hpp.html#adf9d9e0232c7731006e942e6f1eb787c", null ],
    [ "SVD_GIVENS_NEXT_KERNEL", "opencl_2matrix__operations_8hpp.html#ae14982b121ba058e0cc0569b93f80646", null ],
    [ "SVD_HOUSEHOLDER_UPDATE_A_LEFT_KERNEL", "opencl_2matrix__operations_8hpp.html#a86b4bd11f0b1f0b701afa9448cbb865f", null ],
    [ "SVD_HOUSEHOLDER_UPDATE_A_RIGHT_KERNEL", "opencl_2matrix__operations_8hpp.html#a24049445243113b8aff433e4dd6d3c01", null ],
    [ "SVD_HOUSEHOLDER_UPDATE_QL_KERNEL", "opencl_2matrix__operations_8hpp.html#a656519064a982e5904b5a66b5e9c2785", null ]
];